==> chaosmesh-model-5.2.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMOOMSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class JVMOOMSpecFluentImpl<A extends JVMOOMSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements JVMOOMSpecFluent<A> {

    private Boolean after;
    private String area;
    private String block;
    private String classname;
    private Integer interval;
    private String methodname;
    private Boolean wildmode;

    public JVMOOMSpecFluentImpl() {
    }

    public JVMOOMSpecFluentImpl(JVMOOMSpec instance) {
        this.withAfter(instance.getAfter()); 
        this.withArea(instance.getArea()); 
        this.withBlock(instance.getBlock()); 
        this.withClassname(instance.getClassname()); 
        this.withInterval(instance.getInterval()); 
        this.withMethodname(instance.getMethodname()); 
        this.withWildmode(instance.getWildmode()); 
    }

    public Boolean isAfter() {
        return this.after;
    }

    public A withAfter(Boolean after) {
        this.after=after; return (A) this;
    }

    public Boolean hasAfter() {
        return this.after != null;
    }

    public A withNewAfter(String arg1) {
        return (A)withAfter(new Boolean(arg1));
    }

    public A withNewAfter(boolean arg1) {
        return (A)withAfter(new Boolean(arg1));
    }

    public String getArea() {
        return this.area;
    }

    public A withArea(String area) {
        this.area=area; return (A) this;
    }

    public Boolean hasArea() {
        return this.area != null;
    }

    public A withNewArea(String arg1) {
        return (A)withArea(new String(arg1));
    }

    public A withNewArea(StringBuilder arg1) {
        return (A)withArea(new String(arg1));
    }

    public A withNewArea(StringBuffer arg1) {
        return (A)withArea(new String(arg1));
    }

    public String getBlock() {
        return this.block;
    }

    public A withBlock(String block) {
        this.block=block; return (A) this;
    }

    public Boolean hasBlock() {
        return this.block != null;
    }

    public A withNewBlock(String arg1) {
        return (A)withBlock(new String(arg1));
    }

    public A withNewBlock(StringBuilder arg1) {
        return (A)withBlock(new String(arg1));
    }

    public A withNewBlock(StringBuffer arg1) {
        return (A)withBlock(new String(arg1));
    }

    public String getClassname() {
        return this.classname;
    }

    public A withClassname(String classname) {
        this.classname=classname; return (A) this;
    }

    public Boolean hasClassname() {
        return this.classname != null;
    }

    public A withNewClassname(String arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(StringBuilder arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(StringBuffer arg1) {
        return (A)withClassname(new String(arg1));
    }

    public Integer getInterval() {
        return this.interval;
    }

    public A withInterval(Integer interval) {
        this.interval=interval; return (A) this;
    }

    public Boolean hasInterval() {
        return this.interval != null;
    }

    public A withNewInterval(String arg1) {
        return (A)withInterval(new Integer(arg1));
    }

    public A withNewInterval(int arg1) {
        return (A)withInterval(new Integer(arg1));
    }

    public String getMethodname() {
        return this.methodname;
    }

    public A withMethodname(String methodname) {
        this.methodname=methodname; return (A) this;
    }

    public Boolean hasMethodname() {
        return this.methodname != null;
    }

    public A withNewMethodname(String arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(StringBuilder arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(StringBuffer arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public Boolean isWildmode() {
        return this.wildmode;
    }

    public A withWildmode(Boolean wildmode) {
        this.wildmode=wildmode; return (A) this;
    }

    public Boolean hasWildmode() {
        return this.wildmode != null;
    }

    public A withNewWildmode(String arg1) {
        return (A)withWildmode(new Boolean(arg1));
    }

    public A withNewWildmode(boolean arg1) {
        return (A)withWildmode(new Boolean(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        JVMOOMSpecFluentImpl that = (JVMOOMSpecFluentImpl) o;
        if (after != null ? !after.equals(that.after) :that.after != null) return false;
        if (area != null ? !area.equals(that.area) :that.area != null) return false;
        if (block != null ? !block.equals(that.block) :that.block != null) return false;
        if (classname != null ? !classname.equals(that.classname) :that.classname != null) return false;
        if (interval != null ? !interval.equals(that.interval) :that.interval != null) return false;
        if (methodname != null ? !methodname.equals(that.methodname) :that.methodname != null) return false;
        if (wildmode != null ? !wildmode.equals(that.wildmode) :that.wildmode != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(after,  area,  block,  classname,  interval,  methodname,  wildmode,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMOOMSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class JVMOOMSpecFluentImpl<A extends JVMOOMSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements JVMOOMSpecFluent<A> {

    private Boolean after;
    private String area;
    private String block;
    private String classname;
    private Integer interval;
    private String methodname;
    private Boolean wildmode;

    public JVMOOMSpecFluentImpl() {
    }

    public JVMOOMSpecFluentImpl(JVMOOMSpec instance) {
        this.withAfter(instance.getAfter()); 
        this.withArea(instance.getArea()); 
        this.withBlock(instance.getBlock()); 
        this.withClassname(instance.getClassname()); 
        this.withInterval(instance.getInterval()); 
        this.withMethodname(instance.getMethodname()); 
        this.withWildmode(instance.getWildmode()); 
    }

    public Boolean getAfter() {
        return this.after;
    }

    public A withAfter(Boolean after) {
        this.after=after; return (A) this;
    }

    public Boolean hasAfter() {
        return this.after != null;
    }

    public A withNewAfter(String arg1) {
        return (A)withAfter(new Boolean(arg1));
    }

    public A withNewAfter(boolean arg1) {
        return (A)withAfter(new Boolean(arg1));
    }

    public String getArea() {
        return this.area;
    }

    public A withArea(String area) {
        this.area=area; return (A) this;
    }

    public Boolean hasArea() {
        return this.area != null;
    }

    public A withNewArea(StringBuilder arg1) {
        return (A)withArea(new String(arg1));
    }

    public A withNewArea(int[] arg1,int arg2,int arg3) {
        return (A)withArea(new String(arg1, arg2, arg3));
    }

    public A withNewArea(char[] arg1) {
        return (A)withArea(new String(arg1));
    }

    public A withNewArea(StringBuffer arg1) {
        return (A)withArea(new String(arg1));
    }

    public A withNewArea(byte[] arg1,int arg2) {
        return (A)withArea(new String(arg1, arg2));
    }

    public A withNewArea(byte[] arg1) {
        return (A)withArea(new String(arg1));
    }

    public A withNewArea(char[] arg1,int arg2,int arg3) {
        return (A)withArea(new String(arg1, arg2, arg3));
    }

    public A withNewArea(byte[] arg1,int arg2,int arg3) {
        return (A)withArea(new String(arg1, arg2, arg3));
    }

    public A withNewArea(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withArea(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewArea(String arg1) {
        return (A)withArea(new String(arg1));
    }

    public String getBlock() {
        return this.block;
    }

    public A withBlock(String block) {
        this.block=block; return (A) this;
    }

    public Boolean hasBlock() {
        return this.block != null;
    }

    public A withNewBlock(StringBuilder arg1) {
        return (A)withBlock(new String(arg1));
    }

    public A withNewBlock(int[] arg1,int arg2,int arg3) {
        return (A)withBlock(new String(arg1, arg2, arg3));
    }

    public A withNewBlock(char[] arg1) {
        return (A)withBlock(new String(arg1));
    }

    public A withNewBlock(StringBuffer arg1) {
        return (A)withBlock(new String(arg1));
    }

    public A withNewBlock(byte[] arg1,int arg2) {
        return (A)withBlock(new String(arg1, arg2));
    }

    public A withNewBlock(byte[] arg1) {
        return (A)withBlock(new String(arg1));
    }

    public A withNewBlock(char[] arg1,int arg2,int arg3) {
        return (A)withBlock(new String(arg1, arg2, arg3));
    }

    public A withNewBlock(byte[] arg1,int arg2,int arg3) {
        return (A)withBlock(new String(arg1, arg2, arg3));
    }

    public A withNewBlock(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withBlock(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewBlock(String arg1) {
        return (A)withBlock(new String(arg1));
    }

    public String getClassname() {
        return this.classname;
    }

    public A withClassname(String classname) {
        this.classname=classname; return (A) this;
    }

    public Boolean hasClassname() {
        return this.classname != null;
    }

    public A withNewClassname(StringBuilder arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(int[] arg1,int arg2,int arg3) {
        return (A)withClassname(new String(arg1, arg2, arg3));
    }

    public A withNewClassname(char[] arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(StringBuffer arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(byte[] arg1,int arg2) {
        return (A)withClassname(new String(arg1, arg2));
    }

    public A withNewClassname(byte[] arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(char[] arg1,int arg2,int arg3) {
        return (A)withClassname(new String(arg1, arg2, arg3));
    }

    public A withNewClassname(byte[] arg1,int arg2,int arg3) {
        return (A)withClassname(new String(arg1, arg2, arg3));
    }

    public A withNewClassname(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withClassname(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewClassname(String arg1) {
        return (A)withClassname(new String(arg1));
    }

    public Integer getInterval() {
        return this.interval;
    }

    public A withInterval(Integer interval) {
        this.interval=interval; return (A) this;
    }

    public Boolean hasInterval() {
        return this.interval != null;
    }

    public A withNewInterval(int arg0) {
        return (A)withInterval(new Integer(arg0));
    }

    public String getMethodname() {
        return this.methodname;
    }

    public A withMethodname(String methodname) {
        this.methodname=methodname; return (A) this;
    }

    public Boolean hasMethodname() {
        return this.methodname != null;
    }

    public A withNewMethodname(StringBuilder arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(int[] arg1,int arg2,int arg3) {
        return (A)withMethodname(new String(arg1, arg2, arg3));
    }

    public A withNewMethodname(char[] arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(StringBuffer arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(byte[] arg1,int arg2) {
        return (A)withMethodname(new String(arg1, arg2));
    }

    public A withNewMethodname(byte[] arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(char[] arg1,int arg2,int arg3) {
        return (A)withMethodname(new String(arg1, arg2, arg3));
    }

    public A withNewMethodname(byte[] arg1,int arg2,int arg3) {
        return (A)withMethodname(new String(arg1, arg2, arg3));
    }

    public A withNewMethodname(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withMethodname(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewMethodname(String arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public Boolean getWildmode() {
        return this.wildmode;
    }

    public A withWildmode(Boolean wildmode) {
        this.wildmode=wildmode; return (A) this;
    }

    public Boolean hasWildmode() {
        return this.wildmode != null;
    }

    public A withNewWildmode(String arg1) {
        return (A)withWildmode(new Boolean(arg1));
    }

    public A withNewWildmode(boolean arg1) {
        return (A)withWildmode(new Boolean(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        JVMOOMSpecFluentImpl that = (JVMOOMSpecFluentImpl) o;
        if (after != null ? !after.equals(that.after) :that.after != null) return false;
        if (area != null ? !area.equals(that.area) :that.area != null) return false;
        if (block != null ? !block.equals(that.block) :that.block != null) return false;
        if (classname != null ? !classname.equals(that.classname) :that.classname != null) return false;
        if (interval != null ? !interval.equals(that.interval) :that.interval != null) return false;
        if (methodname != null ? !methodname.equals(that.methodname) :that.methodname != null) return false;
        if (wildmode != null ? !wildmode.equals(that.wildmode) :that.wildmode != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(after,  area,  block,  classname,  interval,  methodname,  wildmode,  super.hashCode());
    }

}
